/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.util;

import static org.fortiss.tooling.graphicsGL.ToolingGraphicsGLActivator.PLUGIN_ID;
import static org.fortiss.tooling.graphicsGL.ui.ToolingGraphicsGLUIActivator.getDefault;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;
import static org.fortiss.tooling.kernel.utils.ResourceUtils.getStringContentFromResource;

import java.util.HashMap;
import java.util.List;

import org.fortiss.tooling.graphicsGL.model.Positioned3DBase;
import org.fortiss.tooling.graphicsGL.model.scene.Object3D;
import org.fortiss.tooling.graphicsGL.util.OBJLoaderUtil;
import org.lwjgl.util.vector.Vector3f;

/**
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED Hash:
 */
public class Graph3DUtil {

	/** Array of letters which can be rendered */
	public static final char[] IMPORTED_LETTERS = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I',
			'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z'};
	/** Array of special characters which can be rendered */
	public static final char[] SPECIAL_CHARACTERS = {'?'};

	/** Converts a Positioned3DBase Vector in a Vector3f */
	public static Vector3f convert(Positioned3DBase pos) {
		return new Vector3f(pos.getPosition().getX(), pos.getPosition().getY(), pos.getPosition()
				.getZ());
	}

	/** */
	public static HashMap<String, Object3D> importLetters() {
		HashMap<String, Object3D> mapping = new HashMap<String, Object3D>();

		for(char l : IMPORTED_LETTERS) {
			String path = "/data/letters/" + l;
			Object3D o = getObject(path);
			String key = "" + l;
			mapping.put(key, o);
		}
		return mapping;

	}

	/** Returns the object loaded from the given path. */
	private static Object3D getObject(String modelPath) {
		try {
			List<String> objData = getStringContentFromResource(PLUGIN_ID, modelPath + ".obj");
			List<String> mtlData = getStringContentFromResource(PLUGIN_ID, modelPath + ".mtl");

			return new OBJLoaderUtil(objData, mtlData).getLoadedObjects().get(0);
		} catch(Exception ex) {
			error(getDefault(), ex.getMessage(), ex);
		}
		return null;
	}

}
